@@ -1,6 +1,9 @@
 # Copyright (c) Alibaba, Inc. and its affiliates.
 from .benchmark_mlp import BenchMarkMLP
 from .bninception import BNInception
+from .conv_mae_vit import FastConvMAEViT
+from .conv_vitdet import ConvViTDet
+from .efficientformer import EfficientFormer
 from .genet import PlainNet
 from .hrnet import HRNet
 from .inceptionv3 import Inception3
@@ -9,10 +12,11 @@ from .mae_vit_transformer import *
 from .mnasnet import MNASNet
 from .mobilenetv2 import MobileNetV2
 from .pytorch_image_models_wrapper import *
+from .repvgg_yolox_backbone import RepVGGYOLOX
 from .resnest import ResNeSt
 from .resnet import ResNet
 from .resnet_jit import ResNetJIT
 from .resnext import ResNeXt
 from .shuffle_transformer import ShuffleTransformer
-from .swin_transformer_dynamic import SwinTransformer
+from .swin_transformer import SwinTransformer
 from .vitdet import ViTDet
